from django.conf.urls import patterns, include


urlpatterns = patterns('frontend_notification.views',
    # User notification for Customer UI
    (r'^user_notification/', 'notification_list'),
    (r'^user_notification/', include('notifications.urls')),
    (r'^notification_del_read/(.+)/$', 'notification_del_read'),
    # Notification Status (read/unread) for customer UI
    (r'^update_notification/(\d*)/$', 'update_notification'),
)



from django.template.defaultfilters import register
from django.utils.translation import ugettext_lazy as _


@register.filter(name='notification_style')
def notification_style(val):
    """
    >>> notification_style(1)
    'label-inverse'

    >>> notification_style('')
    'label-success'
    """
    if val:
        return 'label-inverse'
    else:
        return 'label-success'


@register.filter(name='notification_status')
def notification_status(val):
    if val:
        return _('unread').title()
    else:
        return _('read').title()
